summaryrefslogtreecommitdiffstats
path: root/player/screenshot.h
diff options
context:
space:
mode:
Diffstat (limited to 'player/screenshot.h')
-rw-r--r--player/screenshot.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/player/screenshot.h b/player/screenshot.h
index 990cb9503b..97abc79bde 100644
--- a/player/screenshot.h
+++ b/player/screenshot.h
@@ -28,8 +28,8 @@ struct mpv_global;
// One time initialization at program start.
void screenshot_init(struct MPContext *mpctx);
-// Called by the playback core code when a new frame is displayed.
-void screenshot_flip(struct MPContext *mpctx);
+// Called by the playback core on each iteration.
+void handle_each_frame_screenshot(struct MPContext *mpctx);
/* Return the image converted to the given format. If the pixel aspect ratio is
* not 1:1, the image is scaled as well. Returns NULL on failure.